@@ -22,7 +22,7 @@ from anamod.core.losses import Loss
 from anamod.core.perturbations import PERTURBATION_FUNCTIONS, PERTURBATION_MECHANISMS
 from anamod.core.utils import get_logger
 
-Inputs = namedtuple("Inputs", ["data", "targets", "model"])
+Inputs = namedtuple("Inputs", ["data", "targets", "predict"])
 
 
 def main():
@@ -44,7 +44,7 @@ def main():
     parser.add_argument("-window_search_algorithm", type=str)
     parser.add_argument("-window_effect_size_threshold", type=float)
     args = parser.parse_args()
-    args.logger = get_logger(__name__, "%s/worker_%d.log" % (args.output_dir, args.worker_idx))
+    args.logger = get_logger(__name__, f"{args.output_dir}/worker_{args.worker_idx}.log")
     pipeline(args)
 
 
@@ -58,7 +58,8 @@ def pipeline(args):
     data, targets = load_data(args)
     # Load model
     model = load_model(args)
-    inputs = Inputs(data, targets, model)
+    predict = model if callable(model) else model.predict
+    inputs = Inputs(data, targets, predict)
     # Baseline predictions/losses
     # FIXME: baseline may be computed in master and provided to all workers
     baseline_loss, loss_fn = compute_baseline(args, inputs)
@@ -118,8 +119,8 @@ def load_model(args):
 
 def compute_baseline(args, inputs):
     """Compute baseline prediction/loss"""
-    data, targets, model = inputs
-    pred = model.predict(data)
+    data, targets, predict = inputs
+    pred = predict(data)
     loss_fn = Loss(args.loss_function, targets).loss_fn
     baseline_loss = loss_fn(pred)
     args.logger.info(f"Baseline mean loss: {np.mean(baseline_loss)}")
@@ -173,15 +174,15 @@ def perturb_feature_hierarchy(args, inputs, features, baseline_loss, loss_fn):
 
 
 def perturb_feature(args, inputs, feature, loss_fn,
-                    timesteps=..., perturbation_type=constants.ACROSS_INSTANCES):
+                    timesteps=slice(None), perturbation_type=constants.ACROSS_INSTANCES):
     """Perturb feature"""
     # pylint: disable = too-many-arguments, too-many-locals
-    data, _, model = inputs
+    data, _, predict = inputs
     num_permutations = args.num_permutations
     num_elements = data.shape[0]
     perturbed_loss = np.zeros((num_elements, num_permutations))
     if perturbation_type == constants.WITHIN_INSTANCE:
-        num_elements = data.shape[2] if timesteps == ... else len(timesteps)
+        num_elements = len(range(data.shape[2])[timesteps])  # len of slice requires (implicit) sequence
     perturbation_mechanism = get_perturbation_mechanism(args, feature.rng, perturbation_type, num_elements, num_permutations)
     assert args.perturbation == constants.PERMUTATION, "Zeroing deprecated, only permutation-type perturbations currently supported"
     for kidx in range(num_permutations):
@@ -190,7 +191,7 @@ def perturb_feature(args, inputs, feature, loss_fn,
         except StopIteration:
             num_permutations = kidx
             break
-        pred = model.predict(data_perturbed)
+        pred = predict(data_perturbed)
         perturbed_loss[:, kidx] = loss_fn(pred)
     return perturbed_loss[:, :num_permutations]
 
@@ -215,7 +216,7 @@ def compute_importances(args, features, perturbed_losses, baseline_loss):
 def search_window(args, inputs, feature, baseline_loss, loss_fn):
     """Search temporal window of importance for given feature"""
     # pylint: disable = too-many-arguments, too-many-locals
-    args.logger.info("Begin searching for temporal window for feature %s" % feature.name)
+    args.logger.info(f"Begin searching for temporal window for feature {feature.name}")
     overall_effect_size_magnitude = np.abs(feature.overall_effect_size)
     T = inputs.data.shape[2]  # pylint: disable = invalid-name
     # Search left boundary of window by identifying the left inverted window
@@ -224,7 +225,7 @@ def search_window(args, inputs, feature, baseline_loss, loss_fn):
     while current < rbound:
         # Search for the largest 'negative' window anchored on the left that results in a non-important p-value/effect size
         # The right boundary of the left inverted window is the left boundary of the window of interest
-        perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, range(0, current))
+        perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, slice(0, current))
         if args.window_search_algorithm == constants.IMPORTANCE_TEST:
             important = compute_empirical_p_value(baseline_loss, perturbed_loss, args.permutation_test_statistic) < args.importance_significance_level
         else:
@@ -243,7 +244,7 @@ def search_window(args, inputs, feature, baseline_loss, loss_fn):
     # Search right boundary of window by identifying the right inverted window
     lbound, current, rbound = (left, (left + T) // 2, T)
     while lbound < current:
-        perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, range(current, T))
+        perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, slice(current, T))
         if args.window_search_algorithm == constants.IMPORTANCE_TEST:
             important = compute_empirical_p_value(baseline_loss, perturbed_loss, args.permutation_test_statistic) < args.importance_significance_level
         else:
@@ -260,7 +261,7 @@ def search_window(args, inputs, feature, baseline_loss, loss_fn):
             current = (current + lbound) // 2
     right = current
     # Report importance as per significance test
-    perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, range(left, right + 1))
+    perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, slice(left, right + 1))
     # Set attributes on feature
     # TODO: FDR control via Benjamini Hochberg for importance_test algorithm
     # Doesn't seem appropriate though: (i) The p-values are sequentially generated and are not independent, and
@@ -275,7 +276,7 @@ def search_window(args, inputs, feature, baseline_loss, loss_fn):
 def temporal_analysis(args, inputs, features, baseline_loss, loss_fn):
     """Perform temporal analysis of important features"""
     features = [feature for feature in features if feature.important]
-    args.logger.info("Identified important features: %s; proceeding with temporal analysis" % ",".join([feature.name for feature in features]))
+    args.logger.info(f"Identified important features: {','.join([feature.name for feature in features])}; proceeding with temporal analysis")
     for feature in features:
         # Test importance of feature ordering across whole sequence
         perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, perturbation_type=constants.WITHIN_INSTANCE)
@@ -291,7 +292,7 @@ def temporal_analysis(args, inputs, features, baseline_loss, loss_fn):
         feature.window_ordering_important &= feature.window_important
         if feature.window_important:
             # Test importance of feature ordering across window
-            perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, range(left, right + 1), perturbation_type=constants.WITHIN_INSTANCE)
+            perturbed_loss = perturb_feature(args, inputs, feature, loss_fn, slice(left, right + 1), perturbation_type=constants.WITHIN_INSTANCE)
             feature.window_ordering_pvalue = compute_empirical_p_value(baseline_loss, perturbed_loss, args.permutation_test_statistic)
             feature.window_ordering_important = feature.window_ordering_pvalue < args.importance_significance_level
         args.logger.info(f"Found window for feature {feature.name}: ({left}, {right});"
