@@ -45,7 +45,7 @@ def evaluate_hierarchical(args, sfeatures, afeatures):
             importance_map[node.name] = sfeatures_map[sfeature_name].important
             score_map[node.name] = sfeatures_map[sfeature_name].effect_size
         else:
-            importance_map[node.name] = any([importance_map[child.name] for child in node.children])
+            importance_map[node.name] = any(importance_map[child.name] for child in node.children)
     # Overall FDR/power
     important = np.zeros(len(afeatures))
     inferred_important = np.zeros(len(afeatures))
@@ -88,6 +88,8 @@ def evaluate_temporal(args, sfeatures, afeatures):
     """Evaluate results of temporal model analysis - obtain power/FDR measures for importance, temporal importance and windows"""
     # pylint: disable = protected-access, too-many-locals, invalid-name, too-many-statements
     # TODO: Refactor
+    afeatures = list(filter(lambda afeature: len(afeature.idx) == 1, afeatures))  # Only evaluate base features, not feature groups
+    # TODO: Measure power and FDR w.r.t. feature groups as well
     num_features = len(afeatures)
 
     def init_vectors():
